@@ -32,7 +32,7 @@ var searchData=
   ['finalize_29',['Finalize',['../classOpenZWave_1_1Msg.html#a218f357353c68291b7e4da30b04473a0',1,'OpenZWave::Msg']]],
   ['findswitchpoint_30',['FindSwitchPoint',['../classOpenZWave_1_1ValueSchedule.html#a24d2404c18c0f5305f9d05fe076a0636',1,'OpenZWave::ValueSchedule']]],
   ['finishdownload_31',['FinishDownload',['../classOpenZWave_1_1i__HttpClient.html#a44a19286963ee16c1470b678dba44602',1,'OpenZWave::i_HttpClient']]],
-  ['flag_32',['flag',['../structOpenZWave_1_1CompatOptionFlagDefintions.html#a73c0420a7f7abb25d23aa736c69eeb2a',1,'OpenZWave::CompatOptionFlagDefintions::flag()'],['../structOpenZWave_1_1CompatOptionFlagStorage.html#a8d03a621d41a68bda0da295c622c2cc0',1,'OpenZWave::CompatOptionFlagStorage::flag()']]],
+  ['flag_32',['flag',['../structOpenZWave_1_1CompatOptionFlagDefintions.html#a73c0420a7f7abb25d23aa736c69eeb2a',1,'OpenZWave::CompatOptionFlagDefintions::flag'],['../structOpenZWave_1_1CompatOptionFlagStorage.html#a8d03a621d41a68bda0da295c622c2cc0',1,'OpenZWave::CompatOptionFlagStorage::flag']]],
   ['float32_33',['float32',['../Defs_8h.html#aacdc525d6f7bddb3ae95d5c311bd06a1',1,'Defs.h']]],
   ['float64_34',['float64',['../Defs_8h.html#a232fad1b0d6dcc7c16aabde98b2e2a80',1,'Defs.h']]],
   ['foldercreate_35',['FolderCreate',['../classOpenZWave_1_1FileOps.html#aed85e72f755b788ee346e31c3d913ed7',1,'OpenZWave::FileOps']]],
