@@ -4,7 +4,7 @@ var searchData=
   ['thermostatfanstate_1',['ThermostatFanState',['../classOpenZWave_1_1Node.html#ac5c538fa680fa030c40e99af62f68b97',1,'OpenZWave::Node']]],
   ['thermostatmode_2',['ThermostatMode',['../classOpenZWave_1_1Node.html#a65c95a37c7c94a7332b6427da4168b0a',1,'OpenZWave::Node']]],
   ['thermostatoperatingstate_3',['ThermostatOperatingState',['../classOpenZWave_1_1Node.html#aa301316d7a54872660f6574c9749fb0a',1,'OpenZWave::Node']]],
-  ['thermostatsetpoint_4',['ThermostatSetpoint',['../classOpenZWave_1_1Node.html#a255021852df8e3e92a7a24918381b8f4',1,'OpenZWave::Node::ThermostatSetpoint()'],['../classOpenZWave_1_1ValueDecimal.html#a255021852df8e3e92a7a24918381b8f4',1,'OpenZWave::ValueDecimal::ThermostatSetpoint()']]],
+  ['thermostatsetpoint_4',['ThermostatSetpoint',['../classOpenZWave_1_1Node.html#a255021852df8e3e92a7a24918381b8f4',1,'OpenZWave::Node::ThermostatSetpoint'],['../classOpenZWave_1_1ValueDecimal.html#a255021852df8e3e92a7a24918381b8f4',1,'OpenZWave::ValueDecimal::ThermostatSetpoint']]],
   ['threadimpl_5',['ThreadImpl',['../classOpenZWave_1_1Wait.html#ae3c1cdb20d70b22a5c0bf395614eefff',1,'OpenZWave::Wait']]],
   ['timer_6',['Timer',['../classOpenZWave_1_1TimerThread.html#a50de43af5bed41f30c071d8cce0e81bc',1,'OpenZWave::TimerThread']]],
   ['timerthread_7',['TimerThread',['../classOpenZWave_1_1Driver.html#abf471471b27536bbf7f6e8e7d1ff9e53',1,'OpenZWave::Driver']]]
